fmt_as_rfc3339_nanos

Function fmt_as_rfc3339_nanos 

pub fn fmt_as_rfc3339_nanos(t: OffsetDateTime, f: &mut impl Write) -> Result
Helper for formatting an [OffsetDateTime] value.

This function can be used to efficiently format date-time values in Display or Debug implementations.

The format reproduces Go’s time.RFC3339Nano format, ie. a RFC3339 date-time with left-padded subsecond digits without trailing zeros and no trailing dot.